@@ -48,6 +48,14 @@ type fileInfo struct {
 	isDir        bool
 }
 
+type cache interface {
+	init(home string)
+	close()
+	get(key string) (string, bool)
+	// ttl in seconds
+	set(key, value string, ttl int64)
+}
+
 type environmentInfo interface {
 	getenv(key string) string
 	getcwd() string
@@ -77,27 +85,25 @@ type environmentInfo interface {
 	isWsl() bool
 	stackCount() int
 	getTerminalWidth() (int, error)
+	cache() cache
+	close()
 }
 
 type commandCache struct {
-	commands map[string]string
-	lock     sync.RWMutex
+	commands *concurrentMap
 }
 
 func (c *commandCache) set(command, path string) {
-	c.lock.Lock()
-	defer c.lock.Unlock()
-	c.commands[command] = path
+	c.commands.set(command, path)
 }
 
 func (c *commandCache) get(command string) (string, bool) {
-	c.lock.RLock()
-	defer c.lock.RUnlock()
-	if cmd, ok := c.commands[command]; ok {
-		command = cmd
-		return command, true
+	cmd, found := c.commands.get(command)
+	if !found {
+		return "", false
 	}
-	return "", false
+	command, ok := cmd.(string)
+	return command, ok
 }
 
 type tracer struct {
@@ -137,19 +143,20 @@ func (t *tracer) trace(start time.Time, function string, args ...string) {
 }
 
 type environment struct {
-	args     *args
-	cwd      string
-	cmdCache *commandCache
-	tracer   *tracer
+	args      *args
+	cwd       string
+	cmdCache  *commandCache
+	fileCache *fileCache
+	tracer    *tracer
 }
 
 func (env *environment) init(args *args) {
 	env.args = args
-	cmdCache := &commandCache{
-		commands: make(map[string]string),
-		lock:     sync.RWMutex{},
+	env.cmdCache = &commandCache{
+		commands: newConcurrentMap(),
 	}
-	env.cmdCache = cmdCache
+	env.fileCache = &fileCache{}
+	env.fileCache.init(env.homeDir())
 	tracer := &tracer{
 		debug: *args.Debug,
 	}
@@ -472,6 +479,15 @@ func (env *environment) stackCount() int {
 	return *env.args.StackCount
 }
 
+func (env *environment) cache() cache {
+	return env.fileCache
+}
+
+func (env *environment) close() {
+	env.fileCache.close()
+	env.tracer.close()
+}
+
 func cleanHostName(hostName string) string {
 	garbage := []string{
 		".lan",
